@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.471 2017/03/27 08:16:47 fcambus Exp $
+# $OpenBSD: Quirks.pm,v 1.535 2017/09/22 06:39:40 tb Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -99,6 +99,9 @@ my $base_exceptions = {
 	'flex' => '/usr/bin/flex',
 # 6.0
 	'p5-Term-ReadKey' => "$p5a/Term/ReadKey.pm",
+# 6.2
+	'p5-Test-use-ok' => "$p5/Test/use/ok.pm",
+	'p5-Test-Tester' => "$p5/Test/Tester.pm",
 };
 
 my $stem_extensions = {
@@ -411,6 +414,82 @@ my $stem_extensions = {
 	'ja-w3m' => 'w3m',
 	'markdown' => 'py-markdown',
 	'netperf-wrapper' => 'flent',
+	'kamailio-xmlrpc' => 'kamailio-xml',
+# 6.2
+	'qt3d-html' => 'qt5-html',
+	'qtactiveqt-html' => 'qt5-html',
+	'qtbase-html' => 'qt5-html',
+	'qtcanvas3d-html' => 'qt5-html',
+	'qtcharts-html' => 'qt5-html',
+	'qtconnectivity-html' => 'qt5-html',
+	'qtdatavis3d-html' => 'qt5-html',
+	'qtdeclarative-html' => 'qt5-html',
+	'qtdoc-html' => 'qt5-html',
+	'qtgamepad-html' => 'qt5-html',
+	'qtgraphicaleffects-html' => 'qt5-html',
+	'qtimageformats-html' => 'qt5-html',
+	'qtlocation-html' => 'qt5-html',
+	'qtmultimedia-html' => 'qt5-html',
+	'qtnetworkauth-html' => 'qt5-html',
+	'qtpurchasing-html' => 'qt5-html',
+	'qtquickcontrols-html' => 'qt5-html',
+	'qtquickcontrols2-html' => 'qt5-html',
+	'qtremoteobjects-html' => 'qt5-html',
+	'qtscript-html' => 'qt5-html',
+	'qtscxml-html' => 'qt5-html',
+	'qtsensors-html' => 'qt5-html',
+	'qtserialbus-html' => 'qt5-html',
+	'qtserialport-html' => 'qt5-html',
+	'qtspeech-html' => 'qt5-html',
+	'qtsvg-html' => 'qt5-html',
+	'qtvirtualkeyboard-html' => 'qt5-html',
+	'qtwebchannel-html' => 'qt5-html',
+	'qtwebkit-html' => 'qt5-html',
+	'qtwebsockets-html' => 'qt5-html',
+	'qtx11extras-html' => 'qt5-html',
+	'qtxmlpatterns-html' => 'qt5-html',
+
+	'qt3d-qch' => 'qt5-qch',
+	'qtactiveqt-qch' => 'qt5-qch',
+	'qtbase-qch' => 'qt5-qch',
+	'qtcanvas3d-qch' => 'qt5-qch',
+	'qtcharts-qch' => 'qt5-qch',
+	'qtconnectivity-qch' => 'qt5-qch',
+	'qtdatavis3d-qch' => 'qt5-qch',
+	'qtdeclarative-qch' => 'qt5-qch',
+	'qtdoc-qch' => 'qt5-qch',
+	'qtgamepad-qch' => 'qt5-qch',
+	'qtgraphicaleffects-qch' => 'qt5-qch',
+	'qtimageformats-qch' => 'qt5-qch',
+	'qtlocation-qch' => 'qt5-qch',
+	'qtmultimedia-qch' => 'qt5-qch',
+	'qtnetworkauth-qch' => 'qt5-qch',
+	'qtpurchasing-qch' => 'qt5-qch',
+	'qtquickcontrols-qch' => 'qt5-qch',
+	'qtquickcontrols2-qch' => 'qt5-qch',
+	'qtremoteobjects-qch' => 'qt5-qch',
+	'qtscript-qch' => 'qt5-qch',
+	'qtscxml-qch' => 'qt5-qch',
+	'qtsensors-qch' => 'qt5-qch',
+	'qtserialbus-qch' => 'qt5-qch',
+	'qtserialport-qch' => 'qt5-qch',
+	'qtspeech-qch' => 'qt5-qch',
+	'qtsvg-qch' => 'qt5-qch',
+	'qtvirtualkeyboard-qch' => 'qt5-qch',
+	'qtwebchannel-qch' => 'qt5-qch',
+	'qtwebkit-qch' => 'qt5-qch',
+	'qtwebsockets-qch' => 'qt5-qch',
+	'qtx11extras-qch' => 'qt5-qch',
+	'qtxmlpatterns-qch' => 'qt5-qch',
+	'cargo' => 'rust',
+	'apertium-fr-ca' => 'apertium-fra-cat',
+	'py-doit' => 'doit',
+	'cython' => 'py-cython',
+
+	'zarafa' => 'kopano-core',
+	'zarafa-mapi' => 'kopano-mapi',
+	'zarafa-webapp' => 'kopano-webapp',
+	'extract_url' => 'extracturl',
 };
 
 my $obsolete_reason = {
@@ -423,8 +502,6 @@ my $obsolete_reason = {
 	'splitvt' => 0,
 	'bricolage' => 1,
 	'xinha' => 1,
-	'py-cups' => 0,
-	'system-config-printer' => 0,
 	'ruby-postgres' => 3,
 	'metasploit' => 2,
 	'childsplay-plugins' => 3,
@@ -764,12 +841,14 @@ my $obsolete_reason = {
 	'libexude' => 3,
 	'assl' => 3,
 	'libxmlsd' => 3,
+	'p5-I18N-LangTags' => 4,
 	'p5-Text-Restructured' => 3,
 	'p5-Safe-World' => 3,
 	'p5-Safe-Hole' => 3,
 	'p5-Slay-Makefile-Gress' => 3,
 	'p5-Slay-Makefile' => 3,
 	'p5-Slay-Maker' => 3,
+	'p5-Test-Harness' => 4,
 	'mpegaudio' => 0,
 	'fvwm95' => 0,
 	'rplay' => 0,
@@ -856,8 +935,6 @@ my $obsolete_reason = {
 	"sudoku-solver" => 3,
 	"clearsilver" => 3,
 	"poppler-qt" => 3,
-
-# KDE3 removals
 	'amarok' => 2,
 	'digikam-doc' => 6,
 	'gwenview-i18n' => 6,
@@ -867,7 +944,6 @@ my $obsolete_reason = {
 	'kdewebdev' => 5,
 	'kmplayer' => 6,
 	'kountdown' => 3,
-	'krusader' => 2,
 	'kslide' => 3,
 	'ktimeclock' => 6,
 	'okle' => 2,
@@ -932,7 +1008,6 @@ my $obsolete_reason = {
 	'bunny' => 3,
 	'jakarta-servletapi' => 5,
 	'ldistfp' => 0,
-	'rednotebook' => 5,
 	'py-webkitgtk' => 2,
 	'xombrero' => 3,
 	'claws-mail-htmlviewer' => 2,
@@ -952,6 +1027,101 @@ my $obsolete_reason = {
 	'pigment' => 3,
 	'py-pigment' => 3,
 	'gogo' => 3,
+	'spectemu' => 3,
+	'pinpoint' => 3,
+	'anjuta' => 3,
+	'libneural' => 5,
+	'toolame' => 5,
+	'gpointing-device-settings' => 3,
+	'ja-jvim' => 3,
+	'teknap' => 6,
+	'trafd' => 4,
+	'topbeat' => 3,
+	'logic2cnf' => 3,
+	'bytebench' => 3,
+	'libdivxdecore' => 5,
+	'xgrab' => 9,
+	'quirc' => 3,
+	'xspread' => 3,
+	'tryton' => 1,
+	'trytond' => 1,
+	'sharity-light' => 6,
+	'py-axiom' => 5,
+	'py-epsilon' => 5,
+	'hellanzb'=> 3,
+	'londonlaw'=> 3,
+	'castle-combat'=> 3,
+	'rxvt' => 2,
+	'irssi-silc' => 3,
+	'teapop' => 3,
+	'daala' => 6,
+	'aiccu' => 6,
+	'samhain' => 5,
+	'samhain-docs' => 5,
+	'samhain-server' => 5,
+	'texapp' => 6,
+	'surf2' => 5,
+	'mrxvt' => 2,
+	'cutegram' => 3,
+	'libqtelegram-aseman-edition' => 5,
+	'qca-tls' => 3,
+	'py-qt5-docs' => 3,
+	'qtenginio' => 3,
+	'qtenginio-docindex' => 3,
+	'qtenginio-examples' => 3,
+	'qtenginio-html' => 3,
+	'qtenginio-qch' => 3,
+	'crxvt' => 2,
+	'qt3d-docindex' => 6,
+	'qtactiveqt-docindex' => 6,
+	'qtbase-docindex' => 6,
+	'qtcanvas3d-docindex' => 6,
+	'qtcharts-docindex' => 6,
+	'qtconnectivity-docindex' => 6,
+	'qtdatavis3d-docindex' => 6,
+	'qtdeclarative-docindex' => 6,
+	'qtdoc-docindex' => 6,
+	'qtgamepad-docindex' => 6,
+	'qtgraphicaleffects-docindex' => 6,
+	'qtimageformats-docindex' => 6,
+	'qtlocation-docindex' => 6,
+	'qtmultimedia-docindex' => 6,
+	'qtnetworkauth-docindex' => 6,
+	'qtpurchasing-docindex' => 6,
+	'qtquickcontrols-docindex' => 6,
+	'qtquickcontrols2-docindex' => 6,
+	'qtremoteobjects-docindex' => 6,
+	'qtscript-docindex' => 6,
+	'qtscxml-docindex' => 6,
+	'qtsensors-docindex' => 6,
+	'qtserialbus-docindex' => 6,
+	'qtserialport-docindex' => 6,
+	'qtspeech-docindex' => 6,
+	'qtsvg-docindex' => 6,
+	'qtvirtualkeyboard-docindex' => 6,
+	'qtwebchannel-docindex' => 6,
+	'qtwebkit-docindex' => 6,
+	'qtwebsockets-docindex' => 6,
+	'qtx11extras-docindex' => 6,
+	'qtxmlpatterns-docindex' => 6,
+	'conkeror' => 3,
+	'xulrunner' => 5,
+	'xulrunner-devel' => 5,
+	'libaccounts-glib' => 6,
+	'mico' => 0,
+	'leveldb' => 5,
+	'py-graphics' => 3,
+	'akode' => 5,
+	'zendframework' => 5,
+	'kbilliards' => 5,
+	'knutclient' => 5,
+	'pgpsendmail' => 3,
+	'banshee' => 3,
+	'mono-zeroconf' => 5,
+	'mono-avahi' => 5,
+	'toad' => 3,
+	'pgp' => 3,
+	'gonzui' => 3,
 };
 
 # reasons for obsolete packages
@@ -965,6 +1135,7 @@ my @msg = (
 	"no longer useful", #6
 	"removed in favor of using languages package manager", #7
 	"requires systemd", #8
+	"256 colors only, suggest scrot or xwd", #9
 );
 
 # ->is_base_system($handle, $state):
